@@ -7,7 +7,7 @@
 #' @param quantiles income quantile quantiles, usually .50 (median)
 #' @param percent fraction of the quantile, usually .60
 #' @param na.rm Should cases with missing values be dropped?
-#' @param ... arguments passed on to `survey::svyquantile`
+#' @param ... arguments passed on to `survey::oldsvyquantile`
 #'
 #' @details you must run the \code{convey_prep} function on your survey design object immediately after creating it with the \code{svydesign} or \code{svrepdesign} function.
 #'
@@ -131,7 +131,7 @@ svyarpt.survey.design <-
 
 		wf <- 1/full_design$prob
 		htot <- h_fun(incvar, w)
-		q_alpha <- survey::svyquantile(x = formula, design = design, quantiles = quantiles,
+		q_alpha <- survey::oldsvyquantile(x = formula, design = design, quantiles = quantiles,
 		method = "constant", na.rm = na.rm,...)
 		q_alpha <- as.vector(q_alpha)
 		rval <- percent * q_alpha
