@@ -1,8 +1,8 @@
+
 library(testthat)
 library(survey)
 library(vardpoor)
 library(IC2)
+data(api)
 
-# test_check("convey")
-
-
+test_check("convey")
